tietools.is_tie_chain_with_all_leaves_in_same_parent
====================================================

.. autofunction:: abjad.tools.tietools.is_tie_chain_with_all_leaves_in_same_parent.is_tie_chain_with_all_leaves_in_same_parent
